@@ -119,7 +119,6 @@ if TYPE_CHECKING:
 def type(
     model: builtins.type[PydanticModel],
     *,
-    fields: list[str] | None = None,
     name: str | None = None,
     is_input: bool = False,
     is_interface: bool = False,
@@ -132,31 +131,21 @@ def type(
     def wrap(cls: Any) -> builtins.type[StrawberryTypeFromPydantic[PydanticModel]]:
         compat = PydanticCompat.from_model(model)
         model_fields = compat.get_model_fields(model, include_computed=include_computed)
-        original_fields_set = set(fields) if fields else set()
-
-        if fields:
-            warnings.warn(
-                "`fields` is deprecated, use `auto` type annotations instead",
-                DeprecationWarning,
-                stacklevel=2,
-            )
 
         existing_fields = getattr(cls, "__annotations__", {})
 
         # these are the fields that matched a field name in the pydantic model
         # and should copy their alias from the pydantic model
-        fields_set = original_fields_set.union(
-            {name for name, _ in existing_fields.items() if name in model_fields}
-        )
+        fields_set = {
+            name for name, _ in existing_fields.items() if name in model_fields
+        }
         # these are the fields that were marked with strawberry.auto and
         # should copy their type from the pydantic model
-        auto_fields_set = original_fields_set.union(
-            {
-                name
-                for name, type_ in existing_fields.items()
-                if isinstance(type_, StrawberryAuto)
-            }
-        )
+        auto_fields_set = {
+            name
+            for name, type_ in existing_fields.items()
+            if isinstance(type_, StrawberryAuto)
+        }
 
         if all_fields:
             if fields_set:
@@ -303,7 +292,6 @@ def type(
 def input(
     model: builtins.type[PydanticModel],
     *,
-    fields: list[str] | None = None,
     name: str | None = None,
     is_interface: bool = False,
     description: str | None = None,
@@ -319,7 +307,6 @@ def input(
     """
     return type(
         model=model,
-        fields=fields,
         name=name,
         is_input=True,
         is_interface=is_interface,
@@ -333,7 +320,6 @@ def input(
 def interface(
     model: builtins.type[PydanticModel],
     *,
-    fields: list[str] | None = None,
     name: str | None = None,
     is_input: bool = False,
     description: str | None = None,
@@ -349,7 +335,6 @@ def interface(
     """
     return type(
         model=model,
-        fields=fields,
         name=name,
         is_input=is_input,
         is_interface=True,
